<?php

namespace Drupal\store_receipt_validator\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use ReceiptValidator\iTunes\Validator as iTunesValidator;

/**
 * Configure Store receipt validtor settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'store_receipt_validator_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['store_receipt_validator.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['apple'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Apple'),
    ];
    $form['apple']['apple_endpoint'] = [
      '#type' => 'select',
      '#title' => $this->t('Endpoint'),
      '#options' => [
        iTunesValidator::ENDPOINT_SANDBOX => $this->t('Sandbox'),
        iTunesValidator::ENDPOINT_PRODUCTION => $this->t('Production'),
      ],
      '#default_value' => $this->config('store_receipt_validator.settings')->get('apple_endpoint'),
    ];

    $form['apple']['apple_shared_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Shared secret'),
      '#default_value' => $this->config('store_receipt_validator.settings')->get('apple_shared_secret'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('store_receipt_validator.settings')
      ->set('apple_endpoint', $form_state->getValue('apple_endpoint'))
      ->set('apple_shared_secret', $form_state->getValue('apple_shared_secret'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
