<?php

namespace Drupal\store_receipt_validator;

use Drupal\Core\Config\ConfigFactoryInterface;
use GuzzleHttp\ClientInterface;
use ReceiptValidator\iTunes\Validator as iTunesValidator;

/**
 * Client service.
 */
class Validator {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $config;

  /**
   * The HTTP client.
   *
   * @var \GuzzleHttp\ClientInterface
   */
  protected $httpClient;

  /**
   * Constructs a Client object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \GuzzleHttp\ClientInterface $http_client
   *   The HTTP client.
   */
  public function __construct(ConfigFactoryInterface $config_factory, ClientInterface $http_client) {
    $this->config = $config_factory->get('store_receipt_validator.settings');
    $this->httpClient = $http_client;
  }

  /**
   * Get an itunes validator instance.
   *
   * All instances are new as the validator is done to only one validation.
   *
   * @return \ReceiptValidator\iTunes\Validator
   *   Validator.
   */
  protected function itunesValidator() {
    $validator = new iTunesValidator();
    $validator->setSharedSecret($this->config->get('apple_shared_secret'));
    return $validator;
  }

  /**
   * Method description.
   */
  public function validateAppleReceipt(string $receipt) {
    $validator = $this->itunesValidator();
    return $validator->validate($receipt);
  }

}
